-- Filename:     knight_rider.vhd
-- Filetype:     VHDL code 
-- Date:         19 march 2012
-- Update:       13 march 2015
-- Description:  A structural description of a knight_rider
-- Author:       J. op den Brouw
-- State:        demo
-- Error:        -
-- Version:      1.1
-- Copyright:    (c)2015, De Haagse Hogeschool
--

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;

-- Used pin names and what they do:
--
-- clock_50         - input clock (50 MHz)
-- sw(9)            - asynchronous reset
-- ledg(9 downto 0) - shift register output

-- The other port signals are not used but are here for
-- completeness. Please leave the port names in UPPERCASE.
-- VHDL doen't mind, but the Quartus Pin Planner does...

entity knight_rider is
	port (CLOCK_50 : in std_logic;
			BUTTON   : in std_logic_vector(2 downto 0);
			SW       : in std_logic_vector(9 downto 0);
			LEDG     : out std_logic_vector(9 downto 0);
			HEX3_D   : out std_logic_vector(6 downto 0);
			HEX2_D   : out std_logic_vector(6 downto 0);
			HEX1_D   : out std_logic_vector(6 downto 0);
			HEX0_D   : out std_logic_vector(6 downto 0);
			HEX0_DP  : out std_logic;
			HEX1_DP  : out std_logic;
			HEX2_DP  : out std_logic;
			HEX3_DP  : out std_logic
	);
end entity knight_rider;

architecture structural of knight_rider is

-- Needs prescaler
component prescaler is
	generic (freqin : positive := 50000000;
				freqout : positive := 1);
	port (clkin  : in std_logic;
			areset : in std_logic;
			clkout : out std_logic
			);
end component prescaler;

-- Needs shifter


-- Clock output glue signal
signal clock_int : std_logic;
-- 
signal dir_int : std_logic;

begin

   -- Instantiate the prescaler

 	-- Instantiate the shifter
	u1: shifter
	port map (clk => clock_int, areset => sw(9), q => ledg, dir => dir_int);
	
	-- Unused outputs 
	hex0_d <= "1111111";
	hex1_d <= "1111111";
	hex2_d <= "1111111";
	hex3_d <= "1111111";
	
	hex0_dp <= not dir_int;
	hex1_dp <= not clock_int;
	hex2_dp <= '1';
	hex3_dp <= '1';
		
end structural;
